"use strict";
/**
 * The class which holds [[Rate]]s mapped by their abbreviations.
 */
export class Rates {
    /**
     * Adds all rates in the library to be available when parsing.
     */
    static addDefaults() {
        this.add('miles', 'hour', ['mph']);
        this.add('nautical miles', 'hour', ['knot', 'knots']);
        this.add('kilometers', 'hour', ['kph', 'kmph', 'km. hr.', 'k.p.h.', 'k.m.p.h.', 'km:h']);
    }
    /**
     * Adds one or many rates given the unit, rate, and all abbreviations.
     *
     * @param unit The unit.
     * @param rate The rate unit.
     * @param names The list of abbreviations for this rate.
     */
    static add(unit, rate, names) {
        for (let i = 0; i < names.length; i++) {
            this.registered[names[i].toLowerCase()] = { unit, rate };
        }
    }
    /**
     * Gets the rate for the given input or `undefined` if none exists.
     *
     * @param input The input to find a rate for.
     * @return The rate mapped by the input, otherwise `undefined`.
     */
    static get(input) {
        return this.registered[input.toLowerCase()];
    }
}
/**
 * An object of rates mapped by their abbreviation.
 *
 * @see [[Rates.add]]
 */
Rates.registered = {};
//# sourceMappingURL=Rates.js.map