"use strict";
/**
 * An enumeration which specifies what system of measurement a unit belongs to
 * or specifies which system a user desires for output or conversions.
 *
 * @see [[Group]]
 * @see [[Transform]]
 */
export var System;
(function (System) {
    /**
     * The Metrix System of Measurement.
     */
    System[System["METRIC"] = 0] = "METRIC";
    /**
     * The US "traditional systems of weights and measures". Also known as
     * "Standard", "Customary", or, erroneously: "Imperial", or "English".
     */
    System[System["US"] = 1] = "US";
    /**
     * A value for groups when the unit does not belong to a system.
     */
    System[System["NONE"] = 2] = "NONE";
    /**
     * A value for transforms which specify that the user or developer are looking
     * to get results in any system.
     */
    System[System["ANY"] = 3] = "ANY";
    /**
     * A value for transforms which specify that the user or developer are looking
     * to get results in the same system that is already being used for a range.
     * If a current system cannot be determined then any system is returned.
     */
    System[System["GIVEN"] = 4] = "GIVEN";
})(System = System || (System = {}));
//# sourceMappingURL=System.js.map