"use strict";
/**
 * The class which holds [[Rate]]s mapped by their abbreviations.
 */
var Rates = (function () {
    function Rates() {
    }
    /**
     * Adds all rates in the library to be available when parsing.
     */
    Rates.addDefaults = function () {
        this.add('miles', 'hour', ['mph']);
        this.add('nautical miles', 'hour', ['knot', 'knots']);
        this.add('kilometers', 'hour', ['kph', 'kmph', 'km. hr.', 'k.p.h.', 'k.m.p.h.', 'km:h']);
    };
    /**
     * Adds one or many rates given the unit, rate, and all abbreviations.
     *
     * @param unit The unit.
     * @param rate The rate unit.
     * @param names The list of abbreviations for this rate.
     */
    Rates.add = function (unit, rate, names) {
        for (var i = 0; i < names.length; i++) {
            this.registered[names[i].toLowerCase()] = { unit: unit, rate: rate };
        }
    };
    /**
     * Gets the rate for the given input or `undefined` if none exists.
     *
     * @param input The input to find a rate for.
     * @return The rate mapped by the input, otherwise `undefined`.
     */
    Rates.get = function (input) {
        return this.registered[input.toLowerCase()];
    };
    /**
     * An object of rates mapped by their abbreviation.
     *
     * @see [[Rates.add]]
     */
    Rates.registered = {};
    return Rates;
}());
export { Rates };
//# sourceMappingURL=Rates.js.map